#!/bin/sh

PACKAGE=indent
INFODIR=/usr/share/info
INSTALLINFO=/usr/bin/install-info

if [ -x ${INSTALLINFO} -a -f ${INFODIR}/${PACKAGE}.info ] ; then
    ${INSTALLINFO} --dir-file=${INFODIR}/dir ${INFODIR}/${PACKAGE}.info
fi
